@@ -1,14 +1,32 @@
 __author__ = """Clariteia Devs"""
 __email__ = "devs@clariteia.com"
-__version__ = "0.1.1"
+__version__ = "0.2.0"
 
 from .brokers import (
     REPLY_TOPIC_CONTEXT_VAR,
     Broker,
     BrokerSetup,
+    Command,
     CommandBroker,
+    CommandHandler,
+    CommandHandlerService,
+    CommandReply,
     CommandReplyBroker,
+    CommandStatus,
+    Consumer,
+    ConsumerService,
+    DynamicHandler,
+    DynamicHandlerPool,
+    Event,
     EventBroker,
+    EventHandler,
+    EventHandlerService,
+    Handler,
+    HandlerEntry,
+    HandlerRequest,
+    HandlerResponse,
+    HandlerResponseException,
+    HandlerSetup,
     Producer,
     ProducerService,
 )
@@ -44,24 +62,6 @@ from .exceptions import (
     MinosNetworkException,
     MinosRedefinedEnrouteDecoratorException,
 )
-from .handlers import (
-    CommandHandler,
-    CommandHandlerService,
-    CommandReplyHandler,
-    CommandReplyHandlerService,
-    Consumer,
-    ConsumerService,
-    DynamicHandler,
-    DynamicHandlerPool,
-    EventHandler,
-    EventHandlerService,
-    Handler,
-    HandlerEntry,
-    HandlerRequest,
-    HandlerResponse,
-    HandlerResponseException,
-    HandlerSetup,
-)
 from .messages import (
     USER_CONTEXT_VAR,
     Request,
@@ -84,9 +84,6 @@ from .scheduling import (
     ScheduledRequestContent,
     ScheduledResponseException,
 )
-from .snapshots import (
-    SnapshotService,
-)
 from .utils import (
     consume_queue,
     get_host_ip,
