@@ -1,7 +1,12 @@
+from __future__ import (
+    annotations,
+)
+
 from .definitions import (
     BrokerCommandEnrouteDecorator,
     BrokerEventEnrouteDecorator,
     BrokerQueryEnrouteDecorator,
+    PeriodicEventEnrouteDecorator,
     RestCommandEnrouteDecorator,
     RestQueryEnrouteDecorator,
 )
@@ -22,11 +27,18 @@ class RestEnroute:
     query = RestQueryEnrouteDecorator
 
 
+class PeriodicEnroute:
+    """Periodic Enroute class."""
+
+    event = PeriodicEventEnrouteDecorator
+
+
 class Enroute:
     """Enroute decorator main class"""
 
     broker = BrokerEnroute
     rest = RestEnroute
+    periodic = PeriodicEnroute
 
 
 enroute = Enroute
